@@ -27,7 +27,7 @@
 #include "cantor_macros.h"
 
 
-NullBackend::NullBackend( QObject* parent,const QList<QVariant> args ) : Cantor::Backend( parent,args )
+NullBackend::NullBackend( QObject* parent, const QList<QVariant>& args ) : Cantor::Backend( parent,args )
 {
     setObjectName(QLatin1String("nullbackend"));
     qDebug()<<"Creating NullBackend";
@@ -57,6 +57,5 @@ Cantor::Backend::Capabilities NullBackend::capabilities() const
     return Cantor::Backend::Nothing;
 }
 
-K_EXPORT_CANTOR_PLUGIN(nullbackend, NullBackend)
-
+K_PLUGIN_FACTORY_WITH_JSON(nullbackend, "nullbackend.json", registerPlugin<NullBackend>();)
 #include "nullbackend.moc"
