@@ -29,10 +29,10 @@ class NullCompletionObject : public Cantor::CompletionObject
 {
   public:
     NullCompletionObject( const QString& command, int index, NullSession* session);
-    ~NullCompletionObject() override;
+    ~NullCompletionObject() override = default;
 
   protected Q_SLOTS:
-    void fetchCompletions() Q_DECL_OVERRIDE;
+    void fetchCompletions() override;
 
 };
 
