@@ -28,13 +28,11 @@
 #include <helpresult.h>
 
 
-static const char* printCommand = "cantor_print();";
+static const QLatin1String printCommand("cantor_print();");
 
 OctaveExpression::OctaveExpression(Cantor::Session* session, bool internal): Expression(session, internal),
     m_plotPending(false),
-    m_finished(false),
-    m_appendPlotCommand(false),
-    m_appendDot(false)
+    m_finished(false)
 {
     m_plotCommands << QLatin1String("plot") << QLatin1String("semilogx") << QLatin1String("semilogy") << QLatin1String("loglog")
                    << QLatin1String("polar") << QLatin1String("contour") << QLatin1String("bar")
@@ -58,9 +56,6 @@ void OctaveExpression::interrupt()
 {
     qDebug() << "interrupt";
 
-    if (m_appendPlotCommand)
-        removeAppendedPlotCommand();
-
     setStatus(Interrupted);
 }
 
@@ -81,30 +76,60 @@ void OctaveExpression::evaluate()
             }
         }
     }
-    if ( m_plotPending && !cmd.contains(QLatin1String("cantor_plot")) && !cmd.contains(QLatin1String(printCommand)))
-    {
-        // This was a manual plot, we have to add a print command
-        if (!cmd.endsWith(QLatin1Char(';')) && !cmd.endsWith(QLatin1Char(',')))
-        {
-            cmd += QLatin1Char(',');
-            m_appendDot = true;
-        }
-        cmd += QLatin1String(printCommand);
-        setCommand(cmd);
-        m_appendPlotCommand = true;
-    }
+
     m_finished = false;
     session()->enqueueExpression(this);
 }
 
+QString OctaveExpression::internalCommand()
+{
+    QString cmd = command();
+
+    if (m_plotPending && !cmd.contains(QLatin1String("cantor_plot")) && !cmd.contains(printCommand))
+    {
+        if (!cmd.endsWith(QLatin1Char(';')) && !cmd.endsWith(QLatin1Char(',')))
+            cmd += QLatin1Char(',');
+        cmd += printCommand;
+    }
+
+    // We need remove all comments here, because below we merge all strings to one long string
+    // Otherwise, all code after line with comment will be commented out after merging
+    // So, this small state machine remove all comments
+    // FIXME better implementation
+    QString tmp;
+    // 0 - command mode, 1 - string mode for ', 2 - string mode for ", 3 - comment mode
+    int status = 0;
+    for (int i = 0; i < cmd.size(); i++)
+    {
+        const char ch = cmd[i].toLatin1();
+        if (status == 0 && (ch == '#' || ch == '%'))
+            status = 3;
+        else if (status == 0 && ch == '\'')
+            status = 1;
+        else if (status == 0 && ch == '"')
+            status = 2;
+        else if (status == 1 && ch == '\'')
+            status = 0;
+        else if (status == 2 && ch == '"')
+            status = 0;
+        else if (status == 3 && ch == '\n')
+            status = 0;
+
+        if (status != 3)
+            tmp += cmd[i];
+    }
+    cmd = tmp;
+    cmd.replace(QLatin1String(";\n"), QLatin1String(";"));
+    cmd.replace(QLatin1Char('\n'), QLatin1Char(','));
+    cmd += QLatin1Char('\n');
+
+    return cmd;
+}
 
 void OctaveExpression::parseOutput(const QString& output)
 {
     qDebug() << "parseOutput: " << output;
 
-    if (m_appendPlotCommand)
-        removeAppendedPlotCommand();
-
     if (!output.trimmed().isEmpty())
     {
         // TODO: what about help in comment? printf with '... help ...'?
@@ -119,28 +144,6 @@ void OctaveExpression::parseOutput(const QString& output)
         }
     }
 
-    // TODO: remove this, then there is method for notify both Highlighter and variable model about new variable
-    foreach ( const QString& line, output.simplified().split(QLatin1Char('\n'), QString::SkipEmptyParts) )
-    {
-        if ((output.contains(QLatin1Char('='))) && !(command().startsWith(QLatin1String("help(")))
-                && !(command().contains(QLatin1String("help "))) && !(command().contains(QLatin1String("type("))))
-        {
-            qDebug() << line;
-            // Probably a new variable
-            QStringList parts = line.split(QLatin1Char('='));
-            if (parts.size() >= 2)
-            {
-                Cantor::DefaultVariableModel* model = dynamic_cast<Cantor::DefaultVariableModel*>(session()->variableModel());
-                if (model)
-                {
-                    const QString varname = parts.first().trimmed();
-                    if (varname != QLatin1String("__cantor_tmp__"))
-                        model->addVariable(varname, parts.last().trimmed());
-                }
-            }
-        }
-    }
-
     m_finished = true;
     if (!m_plotPending)
         setStatus(Done);
@@ -173,16 +176,3 @@ void OctaveExpression::setPlotPending(bool plot)
 {
     m_plotPending = plot;
 }
-
-void OctaveExpression::removeAppendedPlotCommand()
-{
-    QString cmd = command();
-    cmd.remove(cmd.length()-strlen(printCommand),strlen(printCommand));
-    m_appendPlotCommand = false;
-    if (m_appendDot)
-        {
-        cmd.remove(cmd.length()-1,1);
-        m_appendDot = false;
-        }
-    setCommand(cmd);
-}
