@@ -241,6 +241,14 @@ void SageSession::readStdOut()
                 }
             }
         }
+        else
+        {
+            const QString message = i18n(
+                "Failed to determine the version of Sage. Please check your installation and the output of 'sage -v'.");
+            KMessageBox::error(nullptr, message, i18n("Cantor"));
+            interrupt();
+            logout();
+        }
     }
 
 
@@ -298,12 +306,8 @@ void SageSession::currentExpressionChangedStatus(Cantor::Expression::Status stat
     {
         case Cantor::Expression::Done:
         case Cantor::Expression::Error:
-            expressionQueue().removeFirst();
-            if (expressionQueue().isEmpty())
-                changeStatus(Done);
-            else
-                runFirstExpression();
-            break;
+            finishFirstExpression();
+
         default:
             break;
     }
@@ -387,10 +391,8 @@ void SageSession::interrupt()
             ; //TODO: interrupt the process on windows
 #endif
         }
-        expressionQueue().first()->interrupt();
-        expressionQueue().removeFirst();
         foreach (Cantor::Expression* expression, expressionQueue())
-            expression->setStatus(Cantor::Expression::Done);
+            expression->setStatus(Cantor::Expression::Interrupted);
         expressionQueue().clear();
 
         qDebug()<<"done interrupting";
@@ -488,10 +490,10 @@ bool SageSession::updateSageVersion()
     QRegularExpression versionExp(QLatin1String("(\\d+)\\.(\\d+)"));
     QRegularExpressionMatch version = versionExp.match(versionString);
     qDebug()<<"found version: " << version.capturedTexts();
-    if(version.isValid())
+    if(version.capturedTexts().length() == 3)
     {
-        int major=version.capturedTexts()[1].toInt();
-        int minor=version.capturedTexts()[2].toInt();
+        int major=version.capturedTexts().at(1).toInt();
+        int minor=version.capturedTexts().at(2).toInt();
         m_sageVersion=SageSession::VersionInfo(major, minor);
         return true;
     }
